/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package org.wamblee.security.authorization;

import java.util.logging.Logger;

/**
 * Inititializer class for authorization rules. This class initializes the
 * authorization rules in case none are present.
 */
public class AuthorizationInitializer {
    private static final Logger LOGGER = Logger
        .getLogger(AuthorizationInitializer.class.getName());

    /**
     * Initializes authorization rules in case none are present.
     * 
     * @param aService
     *            Authorization service.
     * @param aRules
     *            Default rules for initialization.
     */
    public AuthorizationInitializer(AuthorizationService aService,
        AbstractAuthorizationRule[] aRules) {
        if (aService.getRules().length == 0) {
            for (AbstractAuthorizationRule rule : aRules) {
                LOGGER.info("Appending authorization rule " + rule);
                aService.appendRule(rule);
            }
        }
    }
}
